@@ -55,7 +55,6 @@
 
 #ifndef ELIDE_CODE
 
-
 /* This needs to come after some library #include
    to get __GNU_LIBRARY__ defined.  */
 #ifdef	__GNU_LIBRARY__
@@ -67,12 +66,12 @@
 
 #ifdef VMS
 #include <unixlib.h>
-#if HAVE_STRING_H - 0
+#endif
+/*#ifdef HAVE_STRING_H*/
 #include <string.h>
-#endif
-#endif
+/*#endif*/
 
-#if defined (WIN32) && !defined (__CYGWIN32__)
+#if defined(_WIN32) && !defined(__CYGWIN32__)
 /* It's not Unix, really.  See?  Capital letters.  */
 #include <windows.h>
 #define getpid() GetCurrentProcessId()
